==> fw4spl_0.9.2.orig.tar.gz: fw4spl-0.9.2/Bundles/LeafVisu/visuVTKAdaptor/src/visuVTKAdaptor/PlaneSelector.cpp <==
/* ***** BEGIN LICENSE BLOCK *****
 * FW4SPL - Copyright (C) IRCAD, 2009-2012.
 * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
 * published by the Free Software Foundation.
 * ****** END LICENSE BLOCK ****** */

#include <boost/foreach.hpp>

#include <fwComEd/CompositeMsg.hpp>
#include <fwComEd/PlaneListMsg.hpp>
#include <fwComEd/PlaneMsg.hpp>

#include <fwServices/Base.hpp>
#include <fwServices/registry/ObjectService.hpp>
#include <fwServices/macros.hpp>
#include <fwServices/IEditionService.hpp>

#include <fwData/Object.hpp>

#include "visuVTKAdaptor/PlaneSelector.hpp"


fwServicesRegisterMacro( ::fwRenderVTK::IVtkAdaptorService, ::visuVTKAdaptor::PlaneSelector, ::fwData::Object ) ;

namespace visuVTKAdaptor
{

PlaneSelector::PlaneSelector() throw()
{
    //handlingEventOff();
}

//------------------------------------------------------------------------------

PlaneSelector::~PlaneSelector() throw()
{
}

//------------------------------------------------------------------------------

void PlaneSelector::configuring() throw(fwTools::Failed)
{
    SLM_TRACE_FUNC();
    assert(m_configuration->getName() == "config");
    //assert(m_configuration->hasAttribute("planelist"));
    //assert(m_configuration->hasAttribute("planeselection"));

    //this->setPlaneListId( m_configuration->getAttributeValue("planelist") );
    //this->setPlaneSelectionId( m_configuration->getAttributeValue("planeselection") );
}

//------------------------------------------------------------------------------

void PlaneSelector::doStart() throw(fwTools::Failed)
{
    SLM_TRACE_FUNC();

    ::fwData::Object::sptr object = ::fwData::Object::dynamicCast(this->getObject());

    if (object)
    {
        m_currentObject = object;
    }
    this->selectObject(object);
}

//------------------------------------------------------------------------------

void PlaneSelector::doUpdate() throw(fwTools::Failed)
{
    SLM_TRACE_FUNC();
    SLM_ASSERT("NOT IMPLEMENTED",false);
}

//------------------------------------------------------------------------------

void PlaneSelector::doSwap() throw(fwTools::Failed)
{
    SLM_TRACE_FUNC();

    ::fwData::Object::sptr object = ::fwData::Object::dynamicCast(this->getObject());
    this->selectObject(object);
}

//------------------------------------------------------------------------------

void PlaneSelector::doStop() throw(fwTools::Failed)
{
    SLM_TRACE_FUNC();

    this->selectObject( ::fwData::Object::sptr() );
}

//------------------------------------------------------------------------------

void PlaneSelector::doReceive( ::fwServices::ObjectMsg::csptr msg) throw(fwTools::Failed)
{
    SLM_TRACE_FUNC();
}

//------------------------------------------------------------------------------

void PlaneSelector::selectObject( ::fwData::Object::sptr object )
{
    SLM_TRACE_FUNC();

    ::fwData::Object::sptr oldObject = m_currentObject.lock();

    if (oldObject != object)
    {
        if (oldObject)
        {
            ::fwComEd::PlaneMsg::sptr deselectMsg = ::fwComEd::PlaneMsg::New();
            deselectMsg->addEvent( ::fwComEd::PlaneMsg::WAS_DESELECTED );
            ::fwServices::IEditionService::notify( this->getSptr(), oldObject, deselectMsg); //TODO: remove option
        }

        m_currentObject.reset();

        if (object)
        {
            if ( object )
            {
                ::fwComEd::PlaneMsg::sptr selectMsg = ::fwComEd::PlaneMsg::New();
                selectMsg->addEvent( ::fwComEd::PlaneMsg::WAS_SELECTED );
                ::fwServices::IEditionService::notify( this->getSptr(), object, selectMsg); //TODO: remove option
            }
            m_currentObject = object;
        }
    }
}

//------------------------------------------------------------------------------

} //namespace visuVTKAdaptor

==> fw4spl_11.0.4.orig.tar.gz: fw4spl-11.0.4/Bundles/LeafVisu/visuVTKAdaptor/src/visuVTKAdaptor/PlaneSelector.cpp <==
/* ***** BEGIN LICENSE BLOCK *****
 * FW4SPL - Copyright (C) IRCAD, 2009-2017.
 * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
 * published by the Free Software Foundation.
 * ****** END LICENSE BLOCK ****** */

#ifndef ANDROID

#include "visuVTKAdaptor/PlaneSelector.hpp"

#include <fwCom/Signal.hpp>
#include <fwCom/Signal.hxx>

#include <fwServices/macros.hpp>

fwServicesRegisterMacro( ::fwRenderVTK::IVtkAdaptorService, ::visuVTKAdaptor::PlaneSelector, ::fwData::Object );

namespace visuVTKAdaptor
{

PlaneSelector::PlaneSelector() throw()
{
}

//------------------------------------------------------------------------------

PlaneSelector::~PlaneSelector() throw()
{
}

//------------------------------------------------------------------------------

void PlaneSelector::doConfigure() throw(fwTools::Failed)
{
    SLM_TRACE_FUNC();
    assert(m_configuration->getName() == "config");
}

//------------------------------------------------------------------------------

void PlaneSelector::doStart() throw(fwTools::Failed)
{
    SLM_TRACE_FUNC();

    ::fwData::Object::sptr object = ::fwData::Object::dynamicCast(this->getObject());

    if (object)
    {
        m_currentObject = object;
    }
    this->selectObject(object);
}

//------------------------------------------------------------------------------

void PlaneSelector::doUpdate() throw(fwTools::Failed)
{
    SLM_ASSERT("NOT IMPLEMENTED", false);
}

//------------------------------------------------------------------------------

void PlaneSelector::doSwap() throw(fwTools::Failed)
{
    ::fwData::Object::sptr object = ::fwData::Object::dynamicCast(this->getObject());
    this->selectObject(object);
}

//------------------------------------------------------------------------------

void PlaneSelector::doStop() throw(fwTools::Failed)
{
    this->selectObject( ::fwData::Object::sptr() );
}

//------------------------------------------------------------------------------

void PlaneSelector::selectObject( ::fwData::Object::sptr object )
{
    ::fwData::Object::sptr oldObject = m_currentObject.lock();

    if (oldObject != object)
    {
        if (oldObject)
        {
            auto sig = oldObject->signal< ::fwData::Plane::SelectedSignalType >(
                ::fwData::Plane::s_SELECTED_SIG);
            sig->asyncEmit(false);
        }

        m_currentObject.reset();

        if (object)
        {
            auto sig = object->signal< ::fwData::Plane::SelectedSignalType >(
                ::fwData::Plane::s_SELECTED_SIG);
            sig->asyncEmit(true);
            m_currentObject = object;
        }
    }
}

//------------------------------------------------------------------------------

} //namespace visuVTKAdaptor

#endif //ANDROID
